Get trend for a single time period
chngest(x, y, single = F)numeric of year values
norm numeric of annually averaged response variable
logical if trends are based on only first and last year of aggregated, i.e., no averaging of first/last three
Estimates trends using methods described in wrtdstrnd. Used internally and is not to be called by the user. Function runs on individual time period groups defined by arguments in wrtdstrnd.