predonobs attributeFill the predonobs attribute
fillpo(dat_in, ...)# S3 method for tidal
fillpo(dat_in, ...)
# S3 method for tidalmean
fillpo(dat_in, ...)
The input tidal or tidalmean object with the filled predonobs attribute as predictions for the observed data as a data frame.
input tidal or tidalmean object
arguments passed to or from other methods
Used in respred to fill the predonobs attribute. This attribute is used to estimate performance metrics with wrtdsperf.