annual_agg: Create annual aggregations of WRTDS output
Description
Create annual aggregations of WRTDS output
Usage
annual_agg(dat_in, ...)# S3 method for default
annual_agg(dat_in, mo_strt = 10, min_mo = 9, logspace = TRUE, ...)
Value
An aggregated data object for plotting, returns only model output and response variable.
Arguments
- dat_in
input tidal or tidalmean object
- ...
arguments passed to or from other methods
- mo_strt
numeric indicating month to start aggregation years, defaults to October for USGS water year from October to September
- min_mo
numeric value from one to twelve indicating the minimum number of months with observations for averaging by years
- logspace
logical indicating if aggregated data are to be shown in log-space or not
Details
WRTDS output is averaged by year for both predictions and flow-normalized predictions. Years are averaged only if one observation is contained in each of the minimum number of months specified by min_mo averaging, otherwise results are not returned for the given year. Note that setting min_mo to values smaller than the default can produce inaccurate trends for years with very few results.
The function is used internally within prdnrmplot and fitplot.
Examples
Run this code## tidal object
annual_agg(tidfit)
## tidalmean object
annual_agg(tidfitmean)
Run the code above in your browser using DataLab